package Qt::Gui::QFocusEvent;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QFocusEvent
# file     : QtGui/qevent.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Core::QEvent/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QFocusEvent

=head1 PUBLIC METHODS

=over

=item   QFocusEvent(QFocusEvent::Type type, Qt::FocusReason reason)

=item   QFocusEvent(QFocusEvent::Type type, Qt::FocusReason reason = Qt::OtherFocusReason)

=item   ~QFocusEvent()

=item  bool gotFocus()

=item  bool lostFocus()

=item  Qt::FocusReason reason()

=item  Qt::FocusReason reason()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
